@@ -14,7 +14,6 @@ from semantic_release.commit_parser import (
     AngularCommitParser,
     EmojiCommitParser,
     ScipyCommitParser,
-    TagCommitParser,
 )
 from semantic_release.hvcs import Bitbucket, Gitea, Github, Gitlab
 
@@ -40,6 +39,9 @@ if TYPE_CHECKING:
 
     ExProjectDir = Path
 
+    class GetWheelFileFn(Protocol):
+        def __call__(self, version_str: str) -> Path: ...
+
     class SetFlagFn(Protocol):
         def __call__(self, flag: bool) -> None: ...
 
@@ -74,6 +76,11 @@ def setup_py_file() -> Path:
     return Path("setup.py")
 
 
+@pytest.fixture(scope="session")
+def dist_dir() -> Path:
+    return Path("dist")
+
+
 @pytest.fixture(scope="session")
 def changelog_md_file() -> Path:
     return Path("CHANGELOG.md")
@@ -99,6 +106,14 @@ def default_rst_changelog_insertion_flag() -> str:
     return f"..{os.linesep}    version list"
 
 
+@pytest.fixture(scope="session")
+def get_wheel_file(dist_dir: Path) -> GetWheelFileFn:
+    def _get_wheel_file(version_str: str) -> Path:
+        return dist_dir / f"{EXAMPLE_PROJECT_NAME}-{version_str}-py3-none-any.whl"
+
+    return _get_wheel_file
+
+
 @pytest.fixture
 def example_project_dir(tmp_path: Path) -> ExProjectDir:
     return tmp_path.resolve()
@@ -249,6 +264,22 @@ def example_setup_py(
     return example_project_dir / setup_py_file
 
 
+@pytest.fixture
+def example_dist_dir(
+    example_project_dir: ExProjectDir,
+    dist_dir: Path,
+) -> Path:
+    return example_project_dir / dist_dir
+
+
+@pytest.fixture
+def example_project_wheel_file(
+    example_dist_dir: Path,
+    get_wheel_file: GetWheelFileFn,
+) -> Path:
+    return example_dist_dir / get_wheel_file(EXAMPLE_PROJECT_VERSION)
+
+
 # Note this is just the path and the content may change
 @pytest.fixture
 def example_changelog_md(
@@ -369,20 +400,6 @@ def use_scipy_parser(
     return _use_scipy_parser
 
 
-@pytest.fixture(scope="session")
-def use_tag_parser(
-    update_pyproject_toml: UpdatePyprojectTomlFn,
-    pyproject_toml_config_option_parser: str,
-) -> UseParserFn:
-    """Modify the configuration file to use the Tag parser."""
-
-    def _use_tag_parser() -> type[CommitParser]:
-        update_pyproject_toml(pyproject_toml_config_option_parser, "tag")
-        return TagCommitParser
-
-    return _use_tag_parser
-
-
 @pytest.fixture(scope="session")
 def use_custom_parser(
     update_pyproject_toml: UpdatePyprojectTomlFn,
