@@ -77,6 +77,7 @@ if TYPE_CHECKING:
         msg: CommitMsg
         type: str
         desc: str
+        scope: str
         mr: str
         sha: str
 
@@ -95,6 +96,7 @@ if TYPE_CHECKING:
             hvcs_domain: str = ...,
             tag_format_str: str | None = None,
             extra_configs: dict[str, TomlSerializableTypes] | None = None,
+            mask_initial_release: bool = False,
         ) -> tuple[Path, HvcsBase]: ...
 
     class CommitNReturnChangelogEntryFn(Protocol):
@@ -145,6 +147,7 @@ if TYPE_CHECKING:
             dest_file: Path | None = None,
             max_version: str | None = None,
             output_format: ChangelogOutputFormat = ChangelogOutputFormat.MARKDOWN,
+            mask_initial_release: bool = False,
         ) -> str: ...
 
     class FormatGitSquashCommitMsgFn(Protocol):
@@ -267,6 +270,7 @@ def get_commit_def_of_angular_commit(
                 "msg": msg,
                 "type": "unknown",
                 "desc": msg,
+                "scope": "",
                 "mr": "",
                 "sha": NULL_HEX_SHA,
             }
@@ -279,6 +283,7 @@ def get_commit_def_of_angular_commit(
             "msg": msg,
             "type": parsed_result.type,
             "desc": str.join("\n\n", descriptions),
+            "scope": parsed_result.scope,
             "mr": parsed_result.linked_merge_request,
             "sha": NULL_HEX_SHA,
         }
@@ -296,6 +301,7 @@ def get_commit_def_of_emoji_commit(
                 "msg": msg,
                 "type": "unknown",
                 "desc": msg,
+                "scope": "",
                 "mr": "",
                 "sha": NULL_HEX_SHA,
             }
@@ -308,6 +314,7 @@ def get_commit_def_of_emoji_commit(
             "msg": msg,
             "type": parsed_result.type,
             "desc": str.join("\n\n", descriptions),
+            "scope": parsed_result.scope,
             "mr": parsed_result.linked_merge_request,
             "sha": NULL_HEX_SHA,
         }
@@ -325,6 +332,7 @@ def get_commit_def_of_scipy_commit(
                 "msg": msg,
                 "type": "unknown",
                 "desc": msg,
+                "scope": "",
                 "mr": "",
                 "sha": NULL_HEX_SHA,
             }
@@ -337,6 +345,7 @@ def get_commit_def_of_scipy_commit(
             "msg": msg,
             "type": parsed_result.type,
             "desc": str.join("\n\n", descriptions),
+            "scope": parsed_result.scope,
             "mr": parsed_result.linked_merge_request,
             "sha": NULL_HEX_SHA,
         }
@@ -637,6 +646,7 @@ def build_configured_base_repo(  # noqa: C901
         hvcs_domain: str = EXAMPLE_HVCS_DOMAIN,
         tag_format_str: str | None = None,
         extra_configs: dict[str, TomlSerializableTypes] | None = None,
+        mask_initial_release: bool = False,
     ) -> tuple[Path, HvcsBase]:
         if not cached_example_git_project.exists():
             raise RuntimeError("Unable to find cached git project files!")
@@ -699,6 +709,12 @@ def build_configured_base_repo(  # noqa: C901
                 ),
             )
 
+            # Set whether or not the initial release should be masked
+            update_pyproject_toml(
+                "tool.semantic_release.changelog.default_templates.mask_initial_release",
+                mask_initial_release,
+            )
+
             # Apply configurations to pyproject.toml
             if extra_configs is not None:
                 for key, value in extra_configs.items():
@@ -748,8 +764,13 @@ def simulate_default_changelog_creation(  # noqa: C901
                 # has a 100 character limit or otherwise our tests will fail because the
                 # URLs and whitespace don't line up
 
-                subject_line = "- {commit_desc}".format(
-                    commit_desc=descriptions[0].capitalize()
+                subject_line = "- {commit_scope}{commit_desc}".format(
+                    commit_desc=descriptions[0].capitalize(),
+                    commit_scope=(
+                        f"**{version_def['commits'][i]['scope']}**: "
+                        if version_def["commits"][i]["scope"]
+                        else ""
+                    ),
                 )
 
                 mr_link = (
@@ -817,19 +838,44 @@ def simulate_default_changelog_creation(  # noqa: C901
 
             for i in section_def["i_commits"]:
                 descriptions = version_def["commits"][i]["desc"].split("\n\n")
-                commit_cl_desc = (
-                    "* {commit_desc} (`{short_sha}`_)\n".format(
-                        commit_desc=descriptions[0].capitalize(),
-                        short_sha=version_def["commits"][i]["sha"][:7],
-                    )
+
+                # NOTE: We have to be wary of the line length as the default changelog
+                # has a 100 character limit or otherwise our tests will fail because the
+                # URLs and whitespace don't line up
+
+                subject_line = "* {commit_scope}{commit_desc}".format(
+                    commit_desc=descriptions[0].capitalize(),
+                    commit_scope=(
+                        f"**{version_def['commits'][i]['scope']}**: "
+                        if version_def["commits"][i]["scope"]
+                        else ""
+                    ),
+                )
+
+                mr_link = (
+                    ""
                     if not version_def["commits"][i]["mr"]
-                    else "* {commit_desc} (`{mr}`_, `{short_sha}`_)\n".format(
-                        commit_desc=descriptions[0].capitalize(),
+                    else "(`{mr}`_,".format(
                         mr=version_def["commits"][i]["mr"],
-                        short_sha=version_def["commits"][i]["sha"][:7],
                     )
                 )
 
+                sha_link = "`{short_sha}`_)".format(
+                    short_sha=version_def["commits"][i]["sha"][:7],
+                )
+                # Add opening parenthesis if no MR link
+                sha_link = sha_link if mr_link else f"({sha_link}"
+
+                # NOTE: we are assuming that the subject line is always less than 100 characters
+                commit_cl_desc = f"{subject_line} {mr_link}".rstrip()
+                if len(commit_cl_desc) > 100:
+                    commit_cl_desc = f"{subject_line}\n  {mr_link}".rstrip()
+
+                if len(f"{commit_cl_desc} {sha_link}") > 100:
+                    commit_cl_desc = f"{commit_cl_desc}\n  {sha_link}\n"
+                else:
+                    commit_cl_desc = f"{commit_cl_desc} {sha_link}\n"
+
                 if len(descriptions) > 1:
                     commit_cl_desc += (
                         "\n" + str.join("\n\n", [*descriptions[1:]]) + "\n"
@@ -880,12 +926,46 @@ def simulate_default_changelog_creation(  # noqa: C901
         }
         return output_functions[output_format](version, version_def, hvcs)
 
+    def build_initial_version_entry(
+        version: VersionStr,
+        version_def: RepoVersionDef,
+        output_format: ChangelogOutputFormat,
+        hvcs: HvcsBase,
+    ) -> str:
+        if output_format == ChangelogOutputFormat.MARKDOWN:
+            return str.join(
+                "\n",
+                [
+                    f"## v{version} ({TODAY_DATE_STR})",
+                    "",
+                    "- Initial Release",
+                    "",
+                ],
+            )
+        if output_format == ChangelogOutputFormat.RESTRUCTURED_TEXT:
+            title = f"v{version} ({TODAY_DATE_STR})"
+            return str.join(
+                "\n",
+                [
+                    f".. _changelog-v{version}:",
+                    "",
+                    title,
+                    "=" * len(title),
+                    "",
+                    "* Initial Release",
+                    "",
+                ],
+            )
+        raise ValueError(f"Unknown output format: {output_format}")
+
     def _mimic_semantic_release_default_changelog(
         repo_definition: RepoDefinition,
         hvcs: HvcsBase,
         dest_file: Path | None = None,
         max_version: str | None = None,
         output_format: ChangelogOutputFormat = ChangelogOutputFormat.MARKDOWN,
+        # TODO: Breaking v10, when default is toggled to true, also change this to True
+        mask_initial_release: bool = False,
     ) -> str:
         if output_format == ChangelogOutputFormat.MARKDOWN:
             header = dedent(
@@ -933,11 +1013,14 @@ def simulate_default_changelog_creation(  # noqa: C901
             )["repo_def"]
         )
 
-        for version, version_def in repo_def.items():
+        for i, (version, version_def) in enumerate(repo_def.items()):
             # prepend entries to force reverse ordering
-            version_entries.insert(
-                0, build_version_entry(version, version_def, output_format, hvcs)
+            entry = (
+                build_initial_version_entry(version, version_def, output_format, hvcs)
+                if i == 0 and mask_initial_release and version != "Unreleased"
+                else build_version_entry(version, version_def, output_format, hvcs)
             )
+            version_entries.insert(0, entry)
 
         changelog_content = (
             str.join(
