@@ -339,6 +339,7 @@ def build_git_flow_repo_with_2_release_channels(
         hvcs_domain: str = EXAMPLE_HVCS_DOMAIN,
         tag_format_str: str | None = None,
         extra_configs: dict[str, TomlSerializableTypes] | None = None,
+        mask_initial_release: bool = False,
     ) -> tuple[Path, HvcsBase]:
         repo_dir, hvcs = build_configured_base_repo(
             dest_dir,
@@ -346,6 +347,7 @@ def build_git_flow_repo_with_2_release_channels(
             hvcs_client_name=hvcs_client_name,
             hvcs_domain=hvcs_domain,
             tag_format_str=tag_format_str,
+            mask_initial_release=mask_initial_release,
             extra_configs={
                 # Set the default release branch
                 "tool.semantic_release.branches.main": {
@@ -391,6 +393,7 @@ def build_git_flow_repo_with_2_release_channels(
                 max_version=next_version,
                 dest_file=repo_dir.joinpath(changelog_md_file),
                 output_format=ChangelogOutputFormat.MARKDOWN,
+                mask_initial_release=mask_initial_release,
             )
 
             # write expected RST changelog to this version
@@ -400,6 +403,7 @@ def build_git_flow_repo_with_2_release_channels(
                 max_version=next_version,
                 dest_file=repo_dir.joinpath(changelog_rst_file),
                 output_format=ChangelogOutputFormat.RESTRUCTURED_TEXT,
+                mask_initial_release=mask_initial_release,
             )
 
             # Publish initial feature release (v0.1.0) [updates tool.poetry.version]
@@ -435,6 +439,7 @@ def build_git_flow_repo_with_2_release_channels(
                 max_version=next_version,
                 dest_file=repo_dir.joinpath(changelog_md_file),
                 output_format=ChangelogOutputFormat.MARKDOWN,
+                mask_initial_release=mask_initial_release,
             )
 
             # write expected RST changelog to this version
@@ -444,6 +449,7 @@ def build_git_flow_repo_with_2_release_channels(
                 max_version=next_version,
                 dest_file=repo_dir.joinpath(changelog_rst_file),
                 output_format=ChangelogOutputFormat.RESTRUCTURED_TEXT,
+                mask_initial_release=mask_initial_release,
             )
 
             # Make a patch level alpha release (v0.1.1-alpha.1)
@@ -467,6 +473,7 @@ def build_git_flow_repo_with_2_release_channels(
                 max_version=next_version,
                 dest_file=repo_dir.joinpath(changelog_md_file),
                 output_format=ChangelogOutputFormat.MARKDOWN,
+                mask_initial_release=mask_initial_release,
             )
 
             # write expected RST changelog to this version
@@ -476,6 +483,7 @@ def build_git_flow_repo_with_2_release_channels(
                 max_version=next_version,
                 dest_file=repo_dir.joinpath(changelog_rst_file),
                 output_format=ChangelogOutputFormat.RESTRUCTURED_TEXT,
+                mask_initial_release=mask_initial_release,
             )
 
             # Make a major feature alpha release (v1.0.0-alpha.1)
@@ -524,6 +532,7 @@ def build_git_flow_repo_with_2_release_channels(
                 max_version=next_version,
                 dest_file=repo_dir.joinpath(changelog_md_file),
                 output_format=ChangelogOutputFormat.MARKDOWN,
+                mask_initial_release=mask_initial_release,
             )
 
             # write expected RST changelog to this version
@@ -533,6 +542,7 @@ def build_git_flow_repo_with_2_release_channels(
                 max_version=next_version,
                 dest_file=repo_dir.joinpath(changelog_rst_file),
                 output_format=ChangelogOutputFormat.RESTRUCTURED_TEXT,
+                mask_initial_release=mask_initial_release,
             )
 
             # Make a major feature release (v1.0.0)
@@ -591,6 +601,7 @@ def build_git_flow_repo_with_2_release_channels(
                 max_version=next_version,
                 dest_file=repo_dir.joinpath(changelog_md_file),
                 output_format=ChangelogOutputFormat.MARKDOWN,
+                mask_initial_release=mask_initial_release,
             )
 
             # write expected RST changelog to this version
@@ -600,6 +611,7 @@ def build_git_flow_repo_with_2_release_channels(
                 max_version=next_version,
                 dest_file=repo_dir.joinpath(changelog_rst_file),
                 output_format=ChangelogOutputFormat.RESTRUCTURED_TEXT,
+                mask_initial_release=mask_initial_release,
             )
 
             # Make a minor feature release (v1.1.0)
@@ -658,6 +670,7 @@ def build_git_flow_repo_with_2_release_channels(
                 max_version=next_version,
                 dest_file=repo_dir.joinpath(changelog_md_file),
                 output_format=ChangelogOutputFormat.MARKDOWN,
+                mask_initial_release=mask_initial_release,
             )
 
             # write expected RST changelog to this version
@@ -667,6 +680,7 @@ def build_git_flow_repo_with_2_release_channels(
                 max_version=next_version,
                 dest_file=repo_dir.joinpath(changelog_rst_file),
                 output_format=ChangelogOutputFormat.RESTRUCTURED_TEXT,
+                mask_initial_release=mask_initial_release,
             )
 
             # Make a patch level release (v1.1.1)
@@ -700,6 +714,7 @@ def build_git_flow_repo_with_2_release_channels(
                 max_version=next_version,
                 dest_file=repo_dir.joinpath(changelog_md_file),
                 output_format=ChangelogOutputFormat.MARKDOWN,
+                mask_initial_release=mask_initial_release,
             )
 
             # write expected RST changelog to this version
@@ -709,6 +724,7 @@ def build_git_flow_repo_with_2_release_channels(
                 max_version=next_version,
                 dest_file=repo_dir.joinpath(changelog_rst_file),
                 output_format=ChangelogOutputFormat.RESTRUCTURED_TEXT,
+                mask_initial_release=mask_initial_release,
             )
 
             # Make an alpha prerelease (v1.2.0-alpha.1) on the feature branch
@@ -731,6 +747,7 @@ def build_git_flow_repo_with_2_release_channels(
                 max_version=next_version,
                 dest_file=repo_dir.joinpath(changelog_md_file),
                 output_format=ChangelogOutputFormat.MARKDOWN,
+                mask_initial_release=mask_initial_release,
             )
 
             # write expected RST changelog to this version
@@ -740,6 +757,7 @@ def build_git_flow_repo_with_2_release_channels(
                 max_version=next_version,
                 dest_file=repo_dir.joinpath(changelog_rst_file),
                 output_format=ChangelogOutputFormat.RESTRUCTURED_TEXT,
+                mask_initial_release=mask_initial_release,
             )
 
             # Make a 2nd alpha prerelease (v1.2.0-alpha.2) on the feature branch
