@@ -381,6 +381,7 @@ def build_git_flow_repo_w_3_release_channels(
         hvcs_domain: str = EXAMPLE_HVCS_DOMAIN,
         tag_format_str: str | None = None,
         extra_configs: dict[str, TomlSerializableTypes] | None = None,
+        mask_initial_release: bool = False,
     ) -> tuple[Path, HvcsBase]:
         repo_dir, hvcs = build_configured_base_repo(
             dest_dir,
@@ -388,6 +389,7 @@ def build_git_flow_repo_w_3_release_channels(
             hvcs_client_name=hvcs_client_name,
             hvcs_domain=hvcs_domain,
             tag_format_str=tag_format_str,
+            mask_initial_release=mask_initial_release,
             extra_configs={
                 # Set the default release branch
                 "tool.semantic_release.branches.main": {
@@ -438,6 +440,7 @@ def build_git_flow_repo_w_3_release_channels(
                 max_version=next_version,
                 dest_file=repo_dir.joinpath(changelog_md_file),
                 output_format=ChangelogOutputFormat.MARKDOWN,
+                mask_initial_release=mask_initial_release,
             )
 
             # write expected RST changelog to this version
@@ -447,6 +450,7 @@ def build_git_flow_repo_w_3_release_channels(
                 max_version=next_version,
                 dest_file=repo_dir.joinpath(changelog_rst_file),
                 output_format=ChangelogOutputFormat.RESTRUCTURED_TEXT,
+                mask_initial_release=mask_initial_release,
             )
 
             # Make initial feature release (v0.1.0)
@@ -481,6 +485,7 @@ def build_git_flow_repo_w_3_release_channels(
                 max_version=next_version,
                 dest_file=repo_dir.joinpath(changelog_md_file),
                 output_format=ChangelogOutputFormat.MARKDOWN,
+                mask_initial_release=mask_initial_release,
             )
 
             # write expected RST changelog to this version
@@ -490,6 +495,7 @@ def build_git_flow_repo_w_3_release_channels(
                 max_version=next_version,
                 dest_file=repo_dir.joinpath(changelog_rst_file),
                 output_format=ChangelogOutputFormat.RESTRUCTURED_TEXT,
+                mask_initial_release=mask_initial_release,
             )
 
             # Make a patch level alpha release (v0.1.1-alpha.1)
@@ -526,6 +532,7 @@ def build_git_flow_repo_w_3_release_channels(
                 max_version=next_version,
                 dest_file=repo_dir.joinpath(changelog_md_file),
                 output_format=ChangelogOutputFormat.MARKDOWN,
+                mask_initial_release=mask_initial_release,
             )
 
             # write expected RST changelog to this version
@@ -535,6 +542,7 @@ def build_git_flow_repo_w_3_release_channels(
                 max_version=next_version,
                 dest_file=repo_dir.joinpath(changelog_rst_file),
                 output_format=ChangelogOutputFormat.RESTRUCTURED_TEXT,
+                mask_initial_release=mask_initial_release,
             )
 
             # Make a major feature release candidate (v1.0.0-rc.1)
@@ -588,6 +596,7 @@ def build_git_flow_repo_w_3_release_channels(
                 max_version=next_version,
                 dest_file=repo_dir.joinpath(changelog_md_file),
                 output_format=ChangelogOutputFormat.MARKDOWN,
+                mask_initial_release=mask_initial_release,
             )
 
             # write expected RST changelog to this version
@@ -597,6 +606,7 @@ def build_git_flow_repo_w_3_release_channels(
                 max_version=next_version,
                 dest_file=repo_dir.joinpath(changelog_rst_file),
                 output_format=ChangelogOutputFormat.RESTRUCTURED_TEXT,
+                mask_initial_release=mask_initial_release,
             )
 
             # Make a major feature release (v1.0.0)
@@ -629,6 +639,7 @@ def build_git_flow_repo_w_3_release_channels(
                 max_version=next_version,
                 dest_file=repo_dir.joinpath(changelog_md_file),
                 output_format=ChangelogOutputFormat.MARKDOWN,
+                mask_initial_release=mask_initial_release,
             )
 
             # write expected RST changelog to this version
@@ -638,6 +649,7 @@ def build_git_flow_repo_w_3_release_channels(
                 max_version=next_version,
                 dest_file=repo_dir.joinpath(changelog_rst_file),
                 output_format=ChangelogOutputFormat.RESTRUCTURED_TEXT,
+                mask_initial_release=mask_initial_release,
             )
 
             # Make a minor bump release candidate (v1.1.0-alpha.1)
@@ -660,6 +672,7 @@ def build_git_flow_repo_w_3_release_channels(
                 max_version=next_version,
                 dest_file=repo_dir.joinpath(changelog_md_file),
                 output_format=ChangelogOutputFormat.MARKDOWN,
+                mask_initial_release=mask_initial_release,
             )
 
             # write expected RST changelog to this version
@@ -669,6 +682,7 @@ def build_git_flow_repo_w_3_release_channels(
                 max_version=next_version,
                 dest_file=repo_dir.joinpath(changelog_rst_file),
                 output_format=ChangelogOutputFormat.RESTRUCTURED_TEXT,
+                mask_initial_release=mask_initial_release,
             )
 
             # Make a 2nd release candidate (v1.1.0-alpha.2)
@@ -723,6 +737,7 @@ def build_git_flow_repo_w_3_release_channels(
                 max_version=next_version,
                 dest_file=repo_dir.joinpath(changelog_md_file),
                 output_format=ChangelogOutputFormat.MARKDOWN,
+                mask_initial_release=mask_initial_release,
             )
 
             # write expected RST changelog to this version
@@ -732,6 +747,7 @@ def build_git_flow_repo_w_3_release_channels(
                 max_version=next_version,
                 dest_file=repo_dir.joinpath(changelog_rst_file),
                 output_format=ChangelogOutputFormat.RESTRUCTURED_TEXT,
+                mask_initial_release=mask_initial_release,
             )
 
             # Make an alpha prerelease (v1.1.0-rc.1)
@@ -774,6 +790,7 @@ def build_git_flow_repo_w_3_release_channels(
                 max_version=next_version,
                 dest_file=repo_dir.joinpath(changelog_md_file),
                 output_format=ChangelogOutputFormat.MARKDOWN,
+                mask_initial_release=mask_initial_release,
             )
 
             # write expected RST changelog to this version
@@ -783,6 +800,7 @@ def build_git_flow_repo_w_3_release_channels(
                 max_version=next_version,
                 dest_file=repo_dir.joinpath(changelog_rst_file),
                 output_format=ChangelogOutputFormat.RESTRUCTURED_TEXT,
+                mask_initial_release=mask_initial_release,
             )
 
             # Make a 2nd alpha prerelease (v1.1.0-rc.2)
@@ -836,6 +854,7 @@ def build_git_flow_repo_w_3_release_channels(
                 max_version=next_version,
                 dest_file=repo_dir.joinpath(changelog_md_file),
                 output_format=ChangelogOutputFormat.MARKDOWN,
+                mask_initial_release=mask_initial_release,
             )
 
             # write expected RST changelog to this version
@@ -845,6 +864,7 @@ def build_git_flow_repo_w_3_release_channels(
                 max_version=next_version,
                 dest_file=repo_dir.joinpath(changelog_rst_file),
                 output_format=ChangelogOutputFormat.RESTRUCTURED_TEXT,
+                mask_initial_release=mask_initial_release,
             )
 
             # Make a 3rd alpha prerelease (v1.1.0)
