@@ -213,6 +213,7 @@ def build_github_flow_repo_w_feature_release_channel(
         hvcs_domain: str = EXAMPLE_HVCS_DOMAIN,
         tag_format_str: str | None = None,
         extra_configs: dict[str, TomlSerializableTypes] | None = None,
+        mask_initial_release: bool = False,
     ) -> tuple[Path, HvcsBase]:
         repo_dir, hvcs = build_configured_base_repo(
             dest_dir,
@@ -220,6 +221,7 @@ def build_github_flow_repo_w_feature_release_channel(
             hvcs_client_name=hvcs_client_name,
             hvcs_domain=hvcs_domain,
             tag_format_str=tag_format_str,
+            mask_initial_release=mask_initial_release,
             extra_configs={
                 # Set the default release branch
                 "tool.semantic_release.branches.main": {
@@ -266,6 +268,7 @@ def build_github_flow_repo_w_feature_release_channel(
                 max_version=next_version,
                 dest_file=repo_dir.joinpath(changelog_md_file),
                 output_format=ChangelogOutputFormat.MARKDOWN,
+                mask_initial_release=mask_initial_release,
             )
 
             # write expected RST changelog to this version
@@ -275,6 +278,7 @@ def build_github_flow_repo_w_feature_release_channel(
                 max_version=next_version,
                 dest_file=repo_dir.joinpath(changelog_rst_file),
                 output_format=ChangelogOutputFormat.RESTRUCTURED_TEXT,
+                mask_initial_release=mask_initial_release,
             )
 
             # Make initial release (v1.0.0)
@@ -303,6 +307,7 @@ def build_github_flow_repo_w_feature_release_channel(
                 max_version=next_version,
                 dest_file=repo_dir.joinpath(changelog_md_file),
                 output_format=ChangelogOutputFormat.MARKDOWN,
+                mask_initial_release=mask_initial_release,
             )
 
             # write expected RST changelog to this version
@@ -312,6 +317,7 @@ def build_github_flow_repo_w_feature_release_channel(
                 max_version=next_version,
                 dest_file=repo_dir.joinpath(changelog_rst_file),
                 output_format=ChangelogOutputFormat.RESTRUCTURED_TEXT,
+                mask_initial_release=mask_initial_release,
             )
 
             # Make a patch level release candidate (v1.0.1-alpha.1)
@@ -334,6 +340,7 @@ def build_github_flow_repo_w_feature_release_channel(
                 max_version=next_version,
                 dest_file=repo_dir.joinpath(changelog_md_file),
                 output_format=ChangelogOutputFormat.MARKDOWN,
+                mask_initial_release=mask_initial_release,
             )
 
             # write expected RST changelog to this version
@@ -343,6 +350,7 @@ def build_github_flow_repo_w_feature_release_channel(
                 max_version=next_version,
                 dest_file=repo_dir.joinpath(changelog_rst_file),
                 output_format=ChangelogOutputFormat.RESTRUCTURED_TEXT,
+                mask_initial_release=mask_initial_release,
             )
 
             # Make an additional prerelease (v1.0.1-alpha.2)
@@ -368,6 +376,7 @@ def build_github_flow_repo_w_feature_release_channel(
                 max_version=next_version,
                 dest_file=repo_dir.joinpath(changelog_md_file),
                 output_format=ChangelogOutputFormat.MARKDOWN,
+                mask_initial_release=mask_initial_release,
             )
 
             # write expected RST changelog to this version
@@ -377,6 +386,7 @@ def build_github_flow_repo_w_feature_release_channel(
                 max_version=next_version,
                 dest_file=repo_dir.joinpath(changelog_rst_file),
                 output_format=ChangelogOutputFormat.RESTRUCTURED_TEXT,
+                mask_initial_release=mask_initial_release,
             )
 
             # Make a patch level release (v1.0.1)
@@ -405,6 +415,7 @@ def build_github_flow_repo_w_feature_release_channel(
                 max_version=next_version,
                 dest_file=repo_dir.joinpath(changelog_md_file),
                 output_format=ChangelogOutputFormat.MARKDOWN,
+                mask_initial_release=mask_initial_release,
             )
 
             # write expected RST changelog to this version
@@ -414,6 +425,7 @@ def build_github_flow_repo_w_feature_release_channel(
                 max_version=next_version,
                 dest_file=repo_dir.joinpath(changelog_rst_file),
                 output_format=ChangelogOutputFormat.RESTRUCTURED_TEXT,
+                mask_initial_release=mask_initial_release,
             )
 
             # Make a patch level release candidate (v1.1.0-alpha.1)
@@ -439,6 +451,7 @@ def build_github_flow_repo_w_feature_release_channel(
                 max_version=next_version,
                 dest_file=repo_dir.joinpath(changelog_md_file),
                 output_format=ChangelogOutputFormat.MARKDOWN,
+                mask_initial_release=mask_initial_release,
             )
 
             # write expected RST changelog to this version
@@ -448,6 +461,7 @@ def build_github_flow_repo_w_feature_release_channel(
                 max_version=next_version,
                 dest_file=repo_dir.joinpath(changelog_rst_file),
                 output_format=ChangelogOutputFormat.RESTRUCTURED_TEXT,
+                mask_initial_release=mask_initial_release,
             )
 
             # Make a minor level release (v1.1.0)
