@@ -64,7 +64,7 @@ def test_parser_returns_correct_bump_level(
     "message, type_",
     [
         ("feat(parser): ...", "features"),
-        ("fix(parser): ...", "fixes"),
+        ("fix(parser): ...", "bug fixes"),
         ("test(parser): ...", "testing"),
         ("docs(parser): ...", "documentation"),
         ("style(parser): ...", "code style"),
@@ -142,6 +142,49 @@ def test_parser_return_subject_from_commit_message(
     assert result.descriptions == descriptions
 
 
+@pytest.mark.parametrize(
+    "message, subject, merge_request_number",
+    # TODO: in v10, we will remove the merge request number from the subject line
+    [
+        # GitHub, Gitea style
+        (
+            "feat(parser): add emoji parser (#123)",
+            "add emoji parser (#123)",
+            "#123",
+        ),
+        # GitLab style
+        (
+            "fix(parser): fix regex in angular parser (!456)",
+            "fix regex in angular parser (!456)",
+            "!456",
+        ),
+        # BitBucket style
+        (
+            "feat(parser): add emoji parser (pull request #123)",
+            "add emoji parser (pull request #123)",
+            "#123",
+        ),
+        # Both a linked merge request and an issue footer (should return the linked merge request)
+        ("fix: superfix (#123)\n\nCloses: #400", "superfix (#123)", "#123"),
+        # None
+        ("fix: superfix", "superfix", ""),
+        # None but includes an issue footer it should not be considered a linked merge request
+        ("fix: superfix\n\nCloses: #400", "superfix", ""),
+    ],
+)
+def test_parser_return_linked_merge_request_from_commit_message(
+    default_angular_parser: AngularCommitParser,
+    message: str,
+    subject: str,
+    merge_request_number: str,
+    make_commit_obj: MakeCommitObjFn,
+):
+    result = default_angular_parser.parse(make_commit_obj(message))
+    assert isinstance(result, ParsedCommit)
+    assert merge_request_number == result.linked_merge_request
+    assert subject == result.descriptions[0]
+
+
 ##############################
 # test custom parser options #
 ##############################
